/*
 * (C) 2023 Motive Commerce Search Corp S.L. <info@motive.co>
 *
 * This file is part of Motive Commerce Search.
 *
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author Motive (motive.co)
 * @copyright (C) 2023 Motive Commerce Search Corp S.L. <info@motive.co>
 * @license https://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 */

var motive = {
	copyToken() {
		document.getElementById('motive-token').select();
		document.execCommand('copy');
		motive.showAlert();
	},
	regenerateToken() {
		const baseUrl = document.getElementById('base-url').value;
		const nonce = document.getElementById('wp-nonce').value;
		const tokenInput = document.getElementById('motive-token');

		fetch(baseUrl + '?rest_route=/motive/admin/regenerate-token', {
			method: 'GET',
			headers: { 'X-WP-Nonce': nonce }
		}).then(res => res.json()).then(newToken => {
			tokenInput.value = '';
			newToken.split('').forEach(function (elem, index) {
				setTimeout(function () {
					tokenInput.value += elem;
				}, index * 32); // 32ms * 32chars ~1 second
			});
		}).catch(() => tokenInput.value = '').finally(motive.hideConfirmDialog);
	},
	showConfirmDialog() {
		document.getElementById('motive-confirm').classList.add('mot-modal--active');
	},
	hideConfirmDialog(e) {
		if (e) {
			e.stopPropagation();
			if (e.target !== this) return;
		}
		document.getElementById('motive-confirm').classList.remove('mot-modal--active');
	},
	showAlert() {
		var alert = document.getElementById('motive-copy-alert');
		alert.style.setProperty('--alert-height', alert.scrollHeight + 'px');
		alert.classList.add('mot-alert--show');
		setTimeout(function () {
			alert.style.setProperty('--alert-height', 'auto');
		}, 555);
	},
	hideAlert(e) {
		e && e.stopPropagation();
		var alert = document.getElementById('motive-copy-alert');
		alert.style.setProperty('--alert-height', alert.scrollHeight + 'px');
		setTimeout(function () {
			alert.style.setProperty('--alert-height', 'auto');
		}, 555);
		setTimeout(function () {
			alert.classList.remove('mot-alert--show');
		}, 0)
	}
}
