<?php
/**
 * (C) 2023 Motive Commerce Search Corp S.L. <info@motive.co>
 *
 * This file is part of Motive Commerce Search.
 *
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author Motive (motive.co)
 * @copyright (C) 2023 Motive Commerce Search Corp S.L. <info@motive.co>
 * @license https://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
 */

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.motive.co
 * @since      1.0.0
 *
 * @package    Motive
 * @subpackage Motive/admin/partials
 */
use Motive\Woocommerce\Token;
?>

<div id="motive" class="">
	<div class="mot-card">
		<img class="mot-card__logo mot-logo" src="<?php echo esc_url( plugins_url( $this->plugin_name ) ); ?>/admin/img/motive-commerce-search-logo.svg" alt="Motive Commerce Search" width="121" height="44">
		<h1 class="mot-card__title">
			<?php esc_html_e( 'Sell more and become a digital trust pioneer', 'motive-commerce-search' ); ?>
		</h1>
		<div class="mot-card__picture">
		<img src="<?php echo esc_url( plugins_url( $this->plugin_name ) ); ?>/admin/img/group19.png" alt="Motive Commerce Search" width="500" height="395">
		</div>
		<div class="mot-card__actions">
		<p class="mot-card__actions-text">
			<?php esc_html_e( 'Motive Commerce Search delivers exceptional experiences for you and your shoppers. An easy to install no-code plugin that can be connected with your catalogue in a matter of minutes.', 'motive-commerce-search' ); ?>
		</p>
		<div class="mot-flex-row">
			<a class="mot-btn mot-btn--primary" target="_blank" href="<?php esc_attr_e( 'https://www.motive.co/try-motive', 'motive-commerce-search' ); ?>">
			<?php esc_html_e( 'Join', 'motive-commerce-search' ); ?>
			</a>
			<a class="mot-btn mot-btn--secondary" target="_blank" href="https://playboard.motive.co/">
			<?php esc_html_e( 'I already have an account', 'motive-commerce-search' ); ?>
			</a>
		</div>
		</div>
		<div class="mot-card__divider">
		<a class="mot-card__powered-by" href="https://empathy.co/" target="_blank">
			<img src="<?php echo esc_url( plugins_url( $this->plugin_name ) ); ?>/admin/img/empathy-logo.svg" alt="<?php esc_attr_e( 'powered by Empathy.co', 'motive-commerce-search' ); ?>" width="180" height="11">
		</a>
		<hr>
		</div>
		<div class="mot-card__form-img">
		<img src="<?php echo esc_url( plugins_url( $this->plugin_name ) ); ?>/admin/img/group2.svg" alt="Motive Commerce Search" width="309" height="107">
		</div>
		<div class="mot-card__form">
		<h2><?php esc_html_e( 'Connect to Motive here', 'motive-commerce-search' ); ?></h2>
		<div class="mot-flex-row">
			<input class="mot-input mot-input--token" type="text" value="<?php echo esc_attr( get_option( Token::MOTIVE_TOKEN ) ); ?>" id="motive-token" readonly onclick="motive.copyToken.apply(this, arguments)"/>
			<button class="mot-btn mot-btn--text" onclick="motive.copyToken.apply(this, arguments)">
			<svg class="mot-btn__icon" xmlns="http://www.w3.org/2000/svg" width="16" height="17">
				<path fill="#2844ff"
					d="M0 2.1A1.6 1.6 0 011.6.5h8a1.6 1.6 0 011.6 1.6v3.2h3.2A1.6 1.6 0 0116 6.9v8a1.6 1.6 0 01-1.6 1.6h-8a1.6 1.6 0 01-1.6-1.6v-3.2H1.6A1.6 1.6 0 010 10.1v-8zm6.4 9.6v3.2h8v-8h-3.2v3.2a1.6 1.6 0 01-1.6 1.6H6.4zm3.2-1.6v-8h-8v8h8z"/>
			</svg>
			<?php esc_html_e( 'Copy token', 'motive-commerce-search' ); ?>
			</button>
		</div>
		<aside class="mot-alert" id="motive-copy-alert">
			<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" class="mot-alert__icon">
			<path d="M12 3.918a8.082 8.082 0 110 16.164 8.082 8.082 0 010-16.164zm0 1a7.082 7.082 0 100 14.164 7.082 7.082 0 000-14.164zm.85 5.527v5.58h-1.71v-5.58h1.71zM12 7.733a1.02 1.02 0 110 2.04 1.02 1.02 0 010-2.04z"></path>
			</svg>
			<main class="mot-alert__body">
			<h5 class="mot-alert__title">
				<?php esc_html_e( 'Security token copied!', 'motive-commerce-search' ); ?>
			</h5>
			<div class="mot-alert__description">
				<?php esc_html_e( 'Your token keeps your shop\'s connection to Motive secure, do not share it with anyone else.', 'motive-commerce-search' ); ?>
			</div>
			</main>
			<button type="button" aria-label="Dismiss" class="mot-alert__close"
					onclick="motive.hideAlert.apply(this, arguments)">
			<svg data-v-2029477c="" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" width="24">
				<path d="M7.597 6.901l.07.058 4.332 4.334 4.335-4.334.07-.058a.5.5 0 01.637.765L12.706 12l4.335 4.335a.5.5 0 01-.638.765l-.07-.058L12 12.706l-4.334 4.335-.07.058a.5.5 0 01-.637-.765l4.334-4.335-4.334-4.333a.5.5 0 01.638-.765z"></path>
			</svg>
			</button>
		</aside>
		<p class="mot-input-hint">
			<?php esc_html_e( 'Token issues? You can', 'motive-commerce-search' ); ?>
			<a href="javascript:void(0)" onclick="motive.showConfirmDialog.apply(this, arguments)">
			<?php esc_html_e( 'get a new token', 'motive-commerce-search' ); ?><br>
			</a>
		</p>
		</div>
	</div>

	<aside class="mot-modal" id="motive-confirm" onclick="motive.hideConfirmDialog.apply(this, arguments)">
		<div class="mot-dialog">
		<input type="hidden" id="wp-nonce" value="<?php echo esc_attr( wp_create_nonce( 'wp_rest' ) ); ?>" />
		<input type="hidden" id="base-url" value="<?php echo esc_attr( get_site_url() ); ?>" />
		<header class="mot-dialog__title">
			<?php esc_html_e( 'Before you click!', 'motive-commerce-search' ); ?>
		</header>
		<main class="mot-dialog__body">
			<p><?php esc_html_e( 'Generating a new token disconnects current links between your shop & Motive so you will need to reconnect it.', 'motive-commerce-search' ); ?></p>
			<p><?php esc_html_e( 'Still need a new token?', 'motive-commerce-search' ); ?></p>
		</main>
		<footer class="mot-dialog__actions">
			<button class="mot-btn mot-btn--secondary" onclick="motive.hideConfirmDialog.apply(this, arguments)">
			<?php esc_html_e( 'Cancel', 'motive-commerce-search' ); ?>
			</button>
			<button class="mot-btn mot-btn--primary" onclick="motive.regenerateToken.apply(this, arguments)">
			<?php esc_html_e( 'Get a new token', 'motive-commerce-search' ); ?>
			</button>
		</footer>
		</div>
	</aside>
</div>
